@@ -5,7 +5,7 @@ use utf8;
 use POSIX qw/setlocale getenv/;
 use Locale::Messages qw(:locale_h :libintl_h);
 use Encode;
-our $VERSION = '1.38';
+our $VERSION = '1.40';
 
 our $share_path = __FILE__;
 $share_path =~ s{\.pm$}{/share/locale};
@@ -210,7 +210,7 @@ sub format_date_ext {
 		} elsif ($days == 1) {
 			#yesterday
 			$formated->{$f} = $formater->( 'yesterday', $date, $seconds);
-		} elsif ( $days < 0 ){
+		} elsif ( $days < 0 || $seconds < 0 ){
 			#in the future
 			$formated->{$f} = $formater->( 'future', $date, $seconds);
 		} else {
